/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0

/* If NAME_PREFIX is specified substitute the variables and functions
   names.  */
#define yyparse msyyparse
#define yylex   msyylex
#define yyerror msyyerror
#define yylval  msyylval
#define yychar  msyychar
#define yydebug msyydebug
#define yynerrs msyynerrs


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NUMBER = 258,
     STRING = 259,
     TIME = 260,
     REGEX = 261,
     OR = 262,
     AND = 263,
     NOT = 264,
     IN = 265,
     GE = 266,
     LE = 267,
     GT = 268,
     LT = 269,
     NE = 270,
     EQ = 271,
     RE = 272,
     LENGTH = 273,
     NEG = 274
   };
#endif
#define NUMBER 258
#define STRING 259
#define TIME 260
#define REGEX 261
#define OR 262
#define AND 263
#define NOT 264
#define IN 265
#define GE 266
#define LE 267
#define GT 268
#define LT 269
#define NE 270
#define EQ 271
#define RE 272
#define LENGTH 273
#define NEG 274




/* Copy the first part of user declarations.  */
#line 5 "mapparser.y"

/* C declarations */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <time.h>

#include "map.h" /* for TRUE/FALSE and REGEX includes */
#include "maptime.h" /* for time comparison routines */

extern int msyylex(void); /* lexer globals */
extern int msyyerror(const char *);

int msyyresult;


/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 24 "mapparser.y"
typedef union YYSTYPE {
  double dblval;
  int intval;  
  char *strval;  
  struct tm tmval;
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 146 "mapparser.c"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 158 "mapparser.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  22
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   195

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  27
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  7
/* YYNRULES -- Number of rules. */
#define YYNRULES  51
/* YYNRULES -- Number of states. */
#define YYNSTATES  101

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   274

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      25,    26,    21,    19,     2,    20,     2,    22,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,    24,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    23
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char yyprhs[] =
{
       0,     0,     3,     4,     6,     8,    10,    14,    18,    22,
      26,    30,    34,    38,    42,    45,    48,    52,    56,    60,
      64,    68,    72,    76,    80,    84,    88,    92,    96,   100,
     104,   108,   112,   116,   120,   124,   128,   132,   136,   138,
     142,   146,   150,   154,   157,   161,   165,   170,   172,   176,
     180,   182
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      28,     0,    -1,    -1,    30,    -1,    31,    -1,     6,    -1,
      30,     7,    30,    -1,    30,     8,    30,    -1,    30,     7,
      31,    -1,    30,     8,    31,    -1,    31,     7,    30,    -1,
      31,     8,    30,    -1,    31,     7,    31,    -1,    31,     8,
      31,    -1,     9,    30,    -1,     9,    31,    -1,    32,    17,
      29,    -1,    31,    16,    31,    -1,    31,    15,    31,    -1,
      31,    13,    31,    -1,    31,    14,    31,    -1,    31,    11,
      31,    -1,    31,    12,    31,    -1,    25,    30,    26,    -1,
      32,    16,    32,    -1,    32,    15,    32,    -1,    32,    13,
      32,    -1,    32,    14,    32,    -1,    32,    11,    32,    -1,
      32,    12,    32,    -1,    33,    16,    33,    -1,    33,    15,
      33,    -1,    33,    13,    33,    -1,    33,    14,    33,    -1,
      33,    11,    33,    -1,    33,    12,    33,    -1,    32,    10,
      32,    -1,    31,    10,    32,    -1,     3,    -1,    31,    19,
      31,    -1,    31,    20,    31,    -1,    31,    21,    31,    -1,
      31,    22,    31,    -1,    20,    31,    -1,    31,    24,    31,
      -1,    25,    31,    26,    -1,    18,    25,    32,    26,    -1,
       4,    -1,    25,    32,    26,    -1,    32,    19,    32,    -1,
       5,    -1,    25,    33,    26,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,    55,    55,    56,    59,    67,    70,    78,    87,    95,
     104,   112,   121,   129,   138,   139,   140,   153,   159,   165,
     171,   177,   183,   189,   190,   196,   202,   208,   214,   220,
     226,   232,   238,   244,   250,   256,   262,   281,   302,   303,
     304,   305,   306,   313,   314,   315,   316,   319,   320,   321,
     324,   325
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "NUMBER", "STRING", "TIME", "REGEX", "OR", 
  "AND", "NOT", "IN", "GE", "LE", "GT", "LT", "NE", "EQ", "RE", "LENGTH", 
  "'+'", "'-'", "'*'", "'/'", "NEG", "'^'", "'('", "')'", "$accept", 
  "input", "regular_exp", "logical_exp", "math_exp", "string_exp", 
  "time_exp", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,    43,
      45,    42,    47,   274,    94,    40,    41
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    27,    28,    28,    28,    29,    30,    30,    30,    30,
      30,    30,    30,    30,    30,    30,    30,    30,    30,    30,
      30,    30,    30,    30,    30,    30,    30,    30,    30,    30,
      30,    30,    30,    30,    30,    30,    30,    30,    31,    31,
      31,    31,    31,    31,    31,    31,    31,    32,    32,    32,
      33,    33
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     0,     1,     1,     1,     3,     3,     3,     3,
       3,     3,     3,     3,     2,     2,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     1,     3,
       3,     3,     3,     2,     3,     3,     4,     1,     3,     3,
       1,     3
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       2,    38,    47,    50,     0,     0,     0,     0,     0,     3,
       4,     0,     0,    14,    15,     0,     0,    43,     0,     0,
       0,     0,     1,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    23,    45,    48,
      51,     6,     8,     7,     9,    10,    12,    11,    13,    37,
      21,    22,    19,    20,    18,    17,    39,    40,    41,    42,
      44,    36,    28,    29,    26,    27,    25,    24,     5,    16,
      49,     0,    34,    35,    32,    33,    31,    30,     0,    46,
       0
};

/* YYDEFGOTO[NTERM-NUM]. */
static const yysigned_char yydefgoto[] =
{
      -1,     8,    89,     9,    10,    11,    12
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -19
static const short yypact[] =
{
      -1,   -19,   -19,   -19,    -1,   -18,    11,    -1,    34,    25,
     109,   156,   173,   -19,    55,    -3,    11,   -11,    13,    89,
     139,   148,   -19,    -1,    -1,    -1,    -1,    -3,    11,    11,
      11,    11,    11,    11,    11,    11,    11,    11,    11,    -3,
      -3,    -3,    -3,    -3,    -3,    -3,    10,    -3,     5,     5,
       5,     5,     5,     5,    -3,   -14,   157,   -19,   -19,   -19,
     -19,    46,   124,   -19,    55,    46,   124,   -19,    55,    37,
     171,   171,   171,   171,   171,   171,    16,    16,   -11,   -11,
     -11,    37,    37,    37,    37,    37,    37,    37,   -19,   -19,
     -19,     5,   -19,   -19,   -19,   -19,   -19,   -19,    -8,   -19,
      31
};

/* YYPGOTO[NTERM-NUM].  */
static const yysigned_char yypgoto[] =
{
     -19,   -19,   -19,     2,    57,     8,    -7
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const unsigned char yytable[] =
{
      21,     2,     1,     2,     3,    47,    13,    15,     4,    18,
       3,    47,    99,    38,     1,    20,    88,     5,    59,     6,
      23,    24,    54,    55,     7,    61,    63,    65,    67,     5,
      91,     6,    23,    24,    22,    69,    16,    36,    37,    57,
      38,    92,    93,    94,    95,    96,    97,    81,    82,    83,
      84,    85,    86,    87,    24,    90,    47,    60,     0,     0,
       0,    14,    98,    17,    19,    27,    28,    29,    30,    31,
      32,    33,     0,    56,    34,    35,    36,    37,     0,    38,
      62,    64,    66,    68,   100,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    25,    26,     0,    27,
      28,    29,    30,    31,    32,    33,     0,     0,    34,    35,
      36,    37,     0,    38,     0,    58,    25,    26,     0,    27,
      28,    29,    30,    31,    32,    33,     0,     0,    34,    35,
      36,    37,    26,    38,    27,    28,    29,    30,    31,    32,
      33,     0,     0,    34,    35,    36,    37,     0,    38,    39,
      40,    41,    42,    43,    44,    45,    46,     0,    47,    48,
      49,    50,    51,    52,    53,    59,    39,    40,    41,    42,
      43,    44,    45,    46,    60,    47,    34,    35,    36,    37,
       0,    38,     0,    58,    48,    49,    50,    51,    52,    53,
      34,    35,    36,    37,     0,    38
};

static const yysigned_char yycheck[] =
{
       7,     4,     3,     4,     5,    19,     4,    25,     9,     7,
       5,    19,    26,    24,     3,     7,     6,    18,    26,    20,
       7,     8,    25,    15,    25,    23,    24,    25,    26,    18,
      25,    20,     7,     8,     0,    27,    25,    21,    22,    26,
      24,    48,    49,    50,    51,    52,    53,    39,    40,    41,
      42,    43,    44,    45,     8,    47,    19,    26,    -1,    -1,
      -1,     4,    54,     6,     7,    10,    11,    12,    13,    14,
      15,    16,    -1,    16,    19,    20,    21,    22,    -1,    24,
      23,    24,    25,    26,    91,    28,    29,    30,    31,    32,
      33,    34,    35,    36,    37,    38,     7,     8,    -1,    10,
      11,    12,    13,    14,    15,    16,    -1,    -1,    19,    20,
      21,    22,    -1,    24,    -1,    26,     7,     8,    -1,    10,
      11,    12,    13,    14,    15,    16,    -1,    -1,    19,    20,
      21,    22,     8,    24,    10,    11,    12,    13,    14,    15,
      16,    -1,    -1,    19,    20,    21,    22,    -1,    24,    10,
      11,    12,    13,    14,    15,    16,    17,    -1,    19,    11,
      12,    13,    14,    15,    16,    26,    10,    11,    12,    13,
      14,    15,    16,    17,    26,    19,    19,    20,    21,    22,
      -1,    24,    -1,    26,    11,    12,    13,    14,    15,    16,
      19,    20,    21,    22,    -1,    24
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,     3,     4,     5,     9,    18,    20,    25,    28,    30,
      31,    32,    33,    30,    31,    25,    25,    31,    30,    31,
      32,    33,     0,     7,     8,     7,     8,    10,    11,    12,
      13,    14,    15,    16,    19,    20,    21,    22,    24,    10,
      11,    12,    13,    14,    15,    16,    17,    19,    11,    12,
      13,    14,    15,    16,    25,    32,    31,    26,    26,    26,
      26,    30,    31,    30,    31,    30,    31,    30,    31,    32,
      31,    31,    31,    31,    31,    31,    31,    31,    31,    31,
      31,    32,    32,    32,    32,    32,    32,    32,     6,    29,
      32,    25,    33,    33,    33,    33,    33,    33,    32,    26,
      33
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1

/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylineno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylineno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  
  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 3:
#line 56 "mapparser.y"
    { 
			    msyyresult = yyvsp[0].intval; 
			  ;}
    break;

  case 4:
#line 59 "mapparser.y"
    {
			    if(yyvsp[0].dblval != 0)
			      msyyresult = MS_TRUE;
			    else
			      msyyresult = MS_FALSE;			    
			  ;}
    break;

  case 6:
#line 70 "mapparser.y"
    {
	                                 if(yyvsp[-2].intval == MS_TRUE)
		                           yyval.intval = MS_TRUE;
		                         else if(yyvsp[0].intval == MS_TRUE)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 7:
#line 78 "mapparser.y"
    {
	                                 if(yyvsp[-2].intval == MS_TRUE) {
			                   if(yyvsp[0].intval == MS_TRUE)
			                     yyval.intval = MS_TRUE;
			                   else
			                     yyval.intval = MS_FALSE;
			                 } else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 8:
#line 87 "mapparser.y"
    {
	                                 if(yyvsp[-2].intval == MS_TRUE)
		                           yyval.intval = MS_TRUE;
		                         else if(yyvsp[0].dblval != 0)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 9:
#line 95 "mapparser.y"
    {
	                                 if(yyvsp[-2].intval == MS_TRUE) {
			                   if(yyvsp[0].dblval != 0)
			                     yyval.intval = MS_TRUE;
			                   else
			                     yyval.intval = MS_FALSE;
			                 } else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 10:
#line 104 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval != 0)
		                           yyval.intval = MS_TRUE;
		                         else if(yyvsp[0].intval == MS_TRUE)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 11:
#line 112 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval != 0) {
			                   if(yyvsp[0].intval == MS_TRUE)
			                     yyval.intval = MS_TRUE;
			                   else
			                     yyval.intval = MS_FALSE;
			                 } else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 12:
#line 121 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval != 0)
		                           yyval.intval = MS_TRUE;
		                         else if(yyvsp[0].dblval != 0)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 13:
#line 129 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval != 0) {
			                   if(yyvsp[0].dblval != 0)
			                     yyval.intval = MS_TRUE;
			                   else
			                     yyval.intval = MS_FALSE;
			                 } else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 14:
#line 138 "mapparser.y"
    { yyval.intval = !yyvsp[0].intval; ;}
    break;

  case 15:
#line 139 "mapparser.y"
    { yyval.intval = !yyvsp[0].dblval; ;}
    break;

  case 16:
#line 140 "mapparser.y"
    {
                                         ms_regex_t re;

                                         if(ms_regcomp(&re, yyvsp[0].strval, MS_REG_EXTENDED|MS_REG_NOSUB) != 0) 
                                           yyval.intval = MS_FALSE;

                                         if(ms_regexec(&re, yyvsp[-2].strval, 0, NULL, 0) == 0)
                                  	   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;

                                         ms_regfree(&re);
                                       ;}
    break;

  case 17:
#line 153 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval == yyvsp[0].dblval)
	 		                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 18:
#line 159 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval != yyvsp[0].dblval)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 19:
#line 165 "mapparser.y"
    {	                                 
	                                 if(yyvsp[-2].dblval > yyvsp[0].dblval)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 20:
#line 171 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval < yyvsp[0].dblval)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 21:
#line 177 "mapparser.y"
    {	                                 
	                                 if(yyvsp[-2].dblval >= yyvsp[0].dblval)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 22:
#line 183 "mapparser.y"
    {
	                                 if(yyvsp[-2].dblval <= yyvsp[0].dblval)
			                   yyval.intval = MS_TRUE;
			                 else
			                   yyval.intval = MS_FALSE;
		                       ;}
    break;

  case 23:
#line 189 "mapparser.y"
    { yyval.intval = yyvsp[-1].intval; ;}
    break;

  case 24:
#line 190 "mapparser.y"
    {
                                         if(strcmp(yyvsp[-2].strval, yyvsp[0].strval) == 0)
					   yyval.intval = MS_TRUE;
					 else
					   yyval.intval = MS_FALSE;
				       ;}
    break;

  case 25:
#line 196 "mapparser.y"
    {
                                         if(strcmp(yyvsp[-2].strval, yyvsp[0].strval) != 0)
					   yyval.intval = MS_TRUE;
					 else
					   yyval.intval = MS_FALSE;
				       ;}
    break;

  case 26:
#line 202 "mapparser.y"
    {
                                         if(strcmp(yyvsp[-2].strval, yyvsp[0].strval) > 0)
					   yyval.intval = MS_TRUE;
					 else
					   yyval.intval = MS_FALSE;
                                       ;}
    break;

  case 27:
#line 208 "mapparser.y"
    {
                                         if(strcmp(yyvsp[-2].strval, yyvsp[0].strval) < 0)
					   yyval.intval = MS_TRUE;
					 else
					   yyval.intval = MS_FALSE;
                                       ;}
    break;

  case 28:
#line 214 "mapparser.y"
    {
                                         if(strcmp(yyvsp[-2].strval, yyvsp[0].strval) >= 0)
					   yyval.intval = MS_TRUE;
					 else
					   yyval.intval = MS_FALSE;
                                       ;}
    break;

  case 29:
#line 220 "mapparser.y"
    {
                                         if(strcmp(yyvsp[-2].strval, yyvsp[0].strval) <= 0)
					   yyval.intval = MS_TRUE;
					 else
					   yyval.intval = MS_FALSE;
                                       ;}
    break;

  case 30:
#line 226 "mapparser.y"
    {
                                     if(msTimeCompare(&(yyvsp[-2].tmval), &(yyvsp[0].tmval)) == 0)
				       yyval.intval = MS_TRUE;
				     else
				       yyval.intval = MS_FALSE;
				   ;}
    break;

  case 31:
#line 232 "mapparser.y"
    {
                                     if(msTimeCompare(&(yyvsp[-2].tmval), &(yyvsp[0].tmval)) != 0)
				       yyval.intval = MS_TRUE;
				     else
				       yyval.intval = MS_FALSE;
				   ;}
    break;

  case 32:
#line 238 "mapparser.y"
    {
                                     if(msTimeCompare(&(yyvsp[-2].tmval), &(yyvsp[0].tmval)) > 0)
				       yyval.intval = MS_TRUE;
				     else
				       yyval.intval = MS_FALSE;
                                   ;}
    break;

  case 33:
#line 244 "mapparser.y"
    {
                                     if(msTimeCompare(&(yyvsp[-2].tmval), &(yyvsp[0].tmval)) < 0)
				       yyval.intval = MS_TRUE;
				     else
				       yyval.intval = MS_FALSE;
                                   ;}
    break;

  case 34:
#line 250 "mapparser.y"
    {
                                     if(msTimeCompare(&(yyvsp[-2].tmval), &(yyvsp[0].tmval)) >= 0)
				       yyval.intval = MS_TRUE;
				     else
				       yyval.intval = MS_FALSE;
                                   ;}
    break;

  case 35:
#line 256 "mapparser.y"
    {
                                     if(msTimeCompare(&(yyvsp[-2].tmval), &(yyvsp[0].tmval)) <= 0)
				       yyval.intval = MS_TRUE;
				     else
				       yyval.intval = MS_FALSE;
                                   ;}
    break;

  case 36:
#line 262 "mapparser.y"
    {
					 char *delim,*bufferp;

					 yyval.intval = MS_FALSE;
					 bufferp=yyvsp[0].strval;

					 while((delim=strchr(bufferp,',')) != NULL) {
					   *delim='\0';
					   if(strcmp(yyvsp[-2].strval,bufferp) == 0) {
					     yyval.intval = MS_TRUE;
					     break;
					   } 
					   *delim=',';
					   bufferp=delim+1;
					 }

					 if(strcmp(yyvsp[-2].strval,bufferp) == 0) // is this test necessary?
					   yyval.intval = MS_TRUE;
				       ;}
    break;

  case 37:
#line 281 "mapparser.y"
    {
					 char *delim,*bufferp;

					 yyval.intval = MS_FALSE;
					 bufferp=yyvsp[0].strval;

					 while((delim=strchr(bufferp,',')) != NULL) {
					   *delim='\0';
					   if(yyvsp[-2].dblval == atof(bufferp)) {
					     yyval.intval = MS_TRUE;
					     break;
					   } 
					   *delim=',';
					   bufferp=delim+1;
					 }

					 if(yyvsp[-2].dblval == atof(bufferp)) // is this test necessary?
					   yyval.intval = MS_TRUE;
				       ;}
    break;

  case 39:
#line 303 "mapparser.y"
    { yyval.dblval = yyvsp[-2].dblval + yyvsp[0].dblval; ;}
    break;

  case 40:
#line 304 "mapparser.y"
    { yyval.dblval = yyvsp[-2].dblval - yyvsp[0].dblval; ;}
    break;

  case 41:
#line 305 "mapparser.y"
    { yyval.dblval = yyvsp[-2].dblval * yyvsp[0].dblval; ;}
    break;

  case 42:
#line 306 "mapparser.y"
    {
	                           if(yyvsp[0].dblval == 0.0) {
				     msyyerror("division by zero");
				     return(-1);
				   } else
	                             yyval.dblval = yyvsp[-2].dblval / yyvsp[0].dblval; 
				 ;}
    break;

  case 43:
#line 313 "mapparser.y"
    { yyval.dblval = yyvsp[0].dblval; ;}
    break;

  case 44:
#line 314 "mapparser.y"
    { yyval.dblval = pow(yyvsp[-2].dblval, yyvsp[0].dblval); ;}
    break;

  case 45:
#line 315 "mapparser.y"
    { yyval.dblval = yyvsp[-1].dblval; ;}
    break;

  case 46:
#line 316 "mapparser.y"
    { yyval.dblval = strlen(yyvsp[-1].strval); ;}
    break;

  case 48:
#line 320 "mapparser.y"
    { yyval.strval = yyvsp[-1].strval; ;}
    break;

  case 49:
#line 321 "mapparser.y"
    { sprintf(yyval.strval, "%s%s", yyvsp[-2].strval, yyvsp[0].strval); ;}
    break;

  case 51:
#line 325 "mapparser.y"
    { yyval.tmval = yyvsp[-1].tmval; ;}
    break;


    }

/* Line 991 of yacc.c.  */
#line 1567 "mapparser.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  char *yymsg;
	  int yyx, yycount;

	  yycount = 0;
	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  for (yyx = yyn < 0 ? -yyn : 0;
	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
	  yysize += yystrlen ("syntax error, unexpected ") + 1;
	  yysize += yystrlen (yytname[yytype]);
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yycount = 0;
		  for (yyx = yyn < 0 ? -yyn : 0;
		       yyx < (int) (sizeof (yytname) / sizeof (char *));
		       yyx++)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			const char *yyq = ! yycount ? ", expecting " : " or ";
			yyp = yystpcpy (yyp, yyq);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yycount++;
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab2;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:

  /* Suppress GCC warning that yyerrlab1 is unused when no action
     invokes YYERROR.  */
#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__)
  __attribute__ ((__unused__))
#endif


  goto yyerrlab2;


/*---------------------------------------------------------------.
| yyerrlab2 -- pop states until the error token can be shifted.  |
`---------------------------------------------------------------*/
yyerrlab2:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 328 "mapparser.y"


